==> huaweicloudsdkworkspace-3.1.133-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/show_quota_details_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowQuotaDetailsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resources': 'list[ResourceNoLimit]',
        'site_id': 'str'
    }

    attribute_map = {
        'resources': 'resources',
        'site_id': 'site_id'
    }

    def __init__(self, resources=None, site_id=None):
        """ShowQuotaDetailsResponse

        The model defined in huaweicloud sdk

        :param resources: 配额资源列表
        :type resources: list[:class:`huaweicloudsdkworkspace.v2.ResourceNoLimit`]
        :param site_id: 站点ID
        :type site_id: str
        """
        
        super(ShowQuotaDetailsResponse, self).__init__()

        self._resources = None
        self._site_id = None
        self.discriminator = None

        self.resources = resources
        if site_id is not None:
            self.site_id = site_id

    @property
    def resources(self):
        """Gets the resources of this ShowQuotaDetailsResponse.

        配额资源列表

        :return: The resources of this ShowQuotaDetailsResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.ResourceNoLimit`]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this ShowQuotaDetailsResponse.

        配额资源列表

        :param resources: The resources of this ShowQuotaDetailsResponse.
        :type resources: list[:class:`huaweicloudsdkworkspace.v2.ResourceNoLimit`]
        """
        self._resources = resources

    @property
    def site_id(self):
        """Gets the site_id of this ShowQuotaDetailsResponse.

        站点ID

        :return: The site_id of this ShowQuotaDetailsResponse.
        :rtype: str
        """
        return self._site_id

    @site_id.setter
    def site_id(self, site_id):
        """Sets the site_id of this ShowQuotaDetailsResponse.

        站点ID

        :param site_id: The site_id of this ShowQuotaDetailsResponse.
        :type site_id: str
        """
        self._site_id = site_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowQuotaDetailsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/show_quota_details_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowQuotaDetailsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resources': 'list[ResourceNoLimit]',
        'site_id': 'str'
    }

    attribute_map = {
        'resources': 'resources',
        'site_id': 'site_id'
    }

    def __init__(self, resources=None, site_id=None):
        r"""ShowQuotaDetailsResponse

        The model defined in huaweicloud sdk

        :param resources: 配额资源列表
        :type resources: list[:class:`huaweicloudsdkworkspace.v2.ResourceNoLimit`]
        :param site_id: 站点ID
        :type site_id: str
        """
        
        super(ShowQuotaDetailsResponse, self).__init__()

        self._resources = None
        self._site_id = None
        self.discriminator = None

        self.resources = resources
        if site_id is not None:
            self.site_id = site_id

    @property
    def resources(self):
        r"""Gets the resources of this ShowQuotaDetailsResponse.

        配额资源列表

        :return: The resources of this ShowQuotaDetailsResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.ResourceNoLimit`]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        r"""Sets the resources of this ShowQuotaDetailsResponse.

        配额资源列表

        :param resources: The resources of this ShowQuotaDetailsResponse.
        :type resources: list[:class:`huaweicloudsdkworkspace.v2.ResourceNoLimit`]
        """
        self._resources = resources

    @property
    def site_id(self):
        r"""Gets the site_id of this ShowQuotaDetailsResponse.

        站点ID

        :return: The site_id of this ShowQuotaDetailsResponse.
        :rtype: str
        """
        return self._site_id

    @site_id.setter
    def site_id(self, site_id):
        r"""Sets the site_id of this ShowQuotaDetailsResponse.

        站点ID

        :param site_id: The site_id of this ShowQuotaDetailsResponse.
        :type site_id: str
        """
        self._site_id = site_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowQuotaDetailsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
